@@ -48,6 +48,7 @@ __all__ = (
     "KeyValuePairTypeDef",
     "LaunchTemplateSpecificationTypeDef",
     "LinuxParametersTypeDef",
+    "LogConfigurationTypeDef",
     "MountPointTypeDef",
     "NetworkInterfaceTypeDef",
     "NodeDetailsTypeDef",
@@ -57,6 +58,8 @@ __all__ = (
     "NodeRangePropertyTypeDef",
     "ResourceRequirementTypeDef",
     "RetryStrategyTypeDef",
+    "SecretTypeDef",
+    "TmpfsTypeDef",
     "UlimitTypeDef",
     "VolumeTypeDef",
     "ArrayPropertiesTypeDef",
@@ -181,6 +184,7 @@ ContainerDetailTypeDef = TypedDict(
         "memory": int,
         "command": List[str],
         "jobRoleArn": str,
+        "executionRoleArn": str,
         "volumes": List["VolumeTypeDef"],
         "environment": List["KeyValuePairTypeDef"],
         "mountPoints": List["MountPointTypeDef"],
@@ -197,6 +201,8 @@ ContainerDetailTypeDef = TypedDict(
         "networkInterfaces": List["NetworkInterfaceTypeDef"],
         "resourceRequirements": List["ResourceRequirementTypeDef"],
         "linuxParameters": "LinuxParametersTypeDef",
+        "logConfiguration": "LogConfigurationTypeDef",
+        "secrets": List["SecretTypeDef"],
     },
     total=False,
 )
@@ -222,6 +228,7 @@ ContainerPropertiesTypeDef = TypedDict(
         "memory": int,
         "command": List[str],
         "jobRoleArn": str,
+        "executionRoleArn": str,
         "volumes": List["VolumeTypeDef"],
         "environment": List["KeyValuePairTypeDef"],
         "mountPoints": List["MountPointTypeDef"],
@@ -232,6 +239,8 @@ ContainerPropertiesTypeDef = TypedDict(
         "instanceType": str,
         "resourceRequirements": List["ResourceRequirementTypeDef"],
         "linuxParameters": "LinuxParametersTypeDef",
+        "logConfiguration": "LogConfigurationTypeDef",
+        "secrets": List["SecretTypeDef"],
     },
     total=False,
 )
@@ -375,9 +384,37 @@ LaunchTemplateSpecificationTypeDef = TypedDict(
 )
 
 LinuxParametersTypeDef = TypedDict(
-    "LinuxParametersTypeDef", {"devices": List["DeviceTypeDef"]}, total=False
+    "LinuxParametersTypeDef",
+    {
+        "devices": List["DeviceTypeDef"],
+        "initProcessEnabled": bool,
+        "sharedMemorySize": int,
+        "tmpfs": List["TmpfsTypeDef"],
+        "maxSwap": int,
+        "swappiness": int,
+    },
+    total=False,
 )
 
+_RequiredLogConfigurationTypeDef = TypedDict(
+    "_RequiredLogConfigurationTypeDef",
+    {
+        "logDriver": Literal[
+            "json-file", "syslog", "journald", "gelf", "fluentd", "awslogs", "splunk"
+        ]
+    },
+)
+_OptionalLogConfigurationTypeDef = TypedDict(
+    "_OptionalLogConfigurationTypeDef",
+    {"options": Dict[str, str], "secretOptions": List["SecretTypeDef"]},
+    total=False,
+)
+
+
+class LogConfigurationTypeDef(_RequiredLogConfigurationTypeDef, _OptionalLogConfigurationTypeDef):
+    pass
+
+
 MountPointTypeDef = TypedDict(
     "MountPointTypeDef", {"containerPath": str, "readOnly": bool, "sourceVolume": str}, total=False
 )
@@ -439,6 +476,16 @@ ResourceRequirementTypeDef = TypedDict(
 
 RetryStrategyTypeDef = TypedDict("RetryStrategyTypeDef", {"attempts": int}, total=False)
 
+SecretTypeDef = TypedDict("SecretTypeDef", {"name": str, "valueFrom": str})
+
+_RequiredTmpfsTypeDef = TypedDict("_RequiredTmpfsTypeDef", {"containerPath": str, "size": int})
+_OptionalTmpfsTypeDef = TypedDict("_OptionalTmpfsTypeDef", {"mountOptions": List[str]}, total=False)
+
+
+class TmpfsTypeDef(_RequiredTmpfsTypeDef, _OptionalTmpfsTypeDef):
+    pass
+
+
 UlimitTypeDef = TypedDict("UlimitTypeDef", {"hardLimit": int, "name": str, "softLimit": int})
 
 VolumeTypeDef = TypedDict("VolumeTypeDef", {"host": "HostTypeDef", "name": str}, total=False)
